/* $Id: basicmode_dlg.cpp 17 2006-12-15 03:39:43Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2006  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "basicmode_dlg.h"
#include "aocrayon.h"
#include "aocolor_widget.h"

#include <QTabWidget>
#include <QPushButton>
#include <QLabel>
#include <QLayout>

BasicModeDlg::BasicModeDlg( QWidget *parent )
	:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	TabWidget = new QTabWidget( this );
	BaseLayout->addWidget( TabWidget );

	/*
	 * Basic Chat colors
	 */
	ChatTab = new QWidget;
	ChatLayout = new QVBoxLayout( ChatTab );
	ChatLayout->setSpacing( 3 );
	ChatLayout->setMargin( 5 );

	ClanBtn = new AOColorWidget( ChatTab );
	ClanBtn->setText( "Org. chat" );
	ClanBtn->addColorGroup( "ctch_clan" );
	ClanBtn->addColorGroup( "CCClanColor" );
	connect( ClanBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( ClanBtn );

	PGroupBtn = new AOColorWidget( ChatTab );
	PGroupBtn->setText( "Private groups" );
	PGroupBtn->addColorGroup( "ctch_pgroup" );
	connect( PGroupBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( PGroupBtn );

	TeamBtn = new AOColorWidget( ChatTab );
	TeamBtn->setText( "Team chat" );
	TeamBtn->addColorGroup( "ctch_team" );
	TeamBtn->addColorGroup( "CCTeamColor" );
	connect( TeamBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( TeamBtn );

	TellBtn = new AOColorWidget( ChatTab );
	TellBtn->setText( "Private tells" );
	TellBtn->addColorGroup( "ct_itell" );
	TellBtn->addColorGroup( "ctch_tell" );
	TellBtn->addColorGroup( "CCTellColor" );
	connect( TellBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( TellBtn );

	VicinityBtn = new AOColorWidget( ChatTab );
	VicinityBtn->setText( "Vicinity" );
	VicinityBtn->addColorGroup( "ctch_vicinity" );
	VicinityBtn->addColorGroup( "CCVicinityColor" );
	connect( VicinityBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( VicinityBtn );

	WhisperBtn = new AOColorWidget( ChatTab );
	WhisperBtn->setText( "Whisper" );
	WhisperBtn->addColorGroup( "ctch_whisper" );
	WhisperBtn->addColorGroup( "CCWhisperColor" );
	connect( WhisperBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( WhisperBtn );

	ShoutBtn = new AOColorWidget( ChatTab );
	ShoutBtn->setText( "Shout" );
	ShoutBtn->addColorGroup( "ctch_shout" );
	ShoutBtn->addColorGroup( "CCShoutColor" );
	connect( ShoutBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( ShoutBtn );

	OOCBtn = new AOColorWidget( ChatTab );
	OOCBtn->setText( "OOC" );
	OOCBtn->addColorGroup( "ctch_newbie" );
	OOCBtn->addColorGroup( "CCNewbieColor" );
	connect( OOCBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	ChatLayout->addWidget( OOCBtn);

	TabWidget->addTab( ChatTab, "Basic Chat" );

	/*
	 * NPC Chat colors
	 */
	NPCTab = new QWidget;
	NPCLayout = new QVBoxLayout( NPCTab );
	NPCLayout->setSpacing( 3 );
	NPCLayout->setMargin( 5 );

	NPCChatBtn = new AOColorWidget( NPCTab );
	NPCChatBtn->setText( "NPC chat text" );
	NPCChatBtn->addColorGroup( "CCNPCChatText" );
	connect( NPCChatBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCChatBtn );

	NPCOOCBtn = new AOColorWidget( NPCTab );
	NPCOOCBtn->setText( "NPC OOC text" );
	NPCOOCBtn->addColorGroup( "CCNPCOOCText" );
	connect( NPCOOCBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCOOCBtn );

	NPCEmoteBtn = new AOColorWidget( NPCTab );
	NPCEmoteBtn->setText( "NPC emotes" );
	NPCEmoteBtn->addColorGroup( "CCNPCChatEmote" );
	connect( NPCEmoteBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCEmoteBtn );

	NPCSystemBtn = new AOColorWidget( NPCTab );
	NPCSystemBtn->setText( "NPC system Text" );
	NPCSystemBtn->addColorGroup( "CCNPCChatSystem" );
	connect( NPCSystemBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCSystemBtn );

	NPCQuestionBtn = new AOColorWidget( NPCTab );
	NPCQuestionBtn->setText( "Your questions" );
	NPCQuestionBtn->addColorGroup( "CCNPCChatQuestion" );
	connect( NPCQuestionBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCQuestionBtn );

	NPCDescriptBtn = new AOColorWidget( NPCTab );
	NPCDescriptBtn->setText( "Descriptions" );
	NPCDescriptBtn->addColorGroup( "CCNPCChatDescription" );
	connect( NPCDescriptBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCDescriptBtn );

	NPCTradeBtn = new AOColorWidget( NPCTab );
	NPCTradeBtn->setText( "Trading text" );
	NPCTradeBtn->addColorGroup( "CCNPCChatTrade" );
	connect( NPCTradeBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	NPCLayout->addWidget( NPCTradeBtn );

	NPCLayout->addStretch( 1 );
	TabWidget->addTab( NPCTab, "NPC Chat" );

	/*
	 * Combat colors
	 */
	CombatTab = new QWidget;
	CombatLayout = new QVBoxLayout( CombatTab );
	CombatLayout->setSpacing( 3 );
	CombatLayout->setMargin( 5 );

	MeHitByNanoBtn = new AOColorWidget( CombatTab );
	MeHitByNanoBtn->setText( "You got hit by nano" );
	MeHitByNanoBtn->addColorGroup( "CCMeHitByNanoColor" );
	connect( MeHitByNanoBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( MeHitByNanoBtn );

	OtherHitByNanoBtn = new AOColorWidget( CombatTab );
	OtherHitByNanoBtn->setText( "n00b got hit by nano" );
	OtherHitByNanoBtn->addColorGroup( "CCOtherHitByNanoColor" );
	connect( OtherHitByNanoBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( OtherHitByNanoBtn );

	MonsterHitMeBtn = new AOColorWidget( CombatTab );
	MonsterHitMeBtn->setText( "You got hit by an NPC" );
	MonsterHitMeBtn->addColorGroup( "CCMonsterHitMeColor" );
	connect( MonsterHitMeBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( MonsterHitMeBtn );

	PlayerHitMeBtn = new AOColorWidget( CombatTab );
	PlayerHitMeBtn->setText( "You got hit by a n00b" );
	PlayerHitMeBtn->addColorGroup( "CCPlayerHitMeColor" );
	connect( PlayerHitMeBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( PlayerHitMeBtn );

	MeHitOtherBtn = new AOColorWidget( CombatTab );
	MeHitOtherBtn->setText( "You hit someone" );
	MeHitOtherBtn->addColorGroup( "CCMeHitOtherColor" );
	connect( MeHitOtherBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( MeHitOtherBtn );

	OtherHitOtherBtn = new AOColorWidget( CombatTab );
	OtherHitOtherBtn->setText( "n00b got hit by other n00b" );
	OtherHitOtherBtn->addColorGroup( "CCOtherHitOtherColor" );
	connect( OtherHitOtherBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( OtherHitOtherBtn );

	OtherHitByPetBtn = new AOColorWidget( CombatTab );
	OtherHitByPetBtn->setText( "n00b got hit by your pet" );
	OtherHitByPetBtn->addColorGroup( "CCOtherHitOtherMyPetColor" );
	connect( OtherHitByPetBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( OtherHitByPetBtn );

	MeHealedBtn = new AOColorWidget( CombatTab );
	MeHealedBtn->setText( "You got healed..." );
	MeHealedBtn->addColorGroup( "CCMeHealedColor" );
	connect( MeHealedBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	CombatLayout->addWidget( MeHealedBtn );

	TabWidget->addTab( CombatTab, "Combat" );

	/*
	 * Misc colors
	 */
	MiscTab = new QWidget;
	MiscLayout = new QVBoxLayout( MiscTab );
	MiscLayout->setSpacing( 3 );
	MiscLayout->setMargin( 5 );

	ShoppingBtn = new AOColorWidget( MiscTab );
	ShoppingBtn->setText( "Shopping channels" );
	ShoppingBtn->addColorGroup( "ctch_seekingteam" );	/* NOTE: Yes, shopping channel uses "seeking team" chat group */
	ShoppingBtn->addColorGroup( "CCSeekingTeamColor" );
	connect( ShoppingBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( ShoppingBtn );

	TowerBtn = new AOColorWidget( MiscTab );
	TowerBtn->setText( "Towers &amp; Org. Msg." );
	TowerBtn->addColorGroup( "ctch_tower" );
	TowerBtn->addColorGroup( "CCTowerColor" );
	connect( TowerBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( TowerBtn );

	MeGotXPBtn = new AOColorWidget( MiscTab );
	MeGotXPBtn->setText( "XP/SK feedback" );
	MeGotXPBtn->addColorGroup( "CCMeGotXpColor" );
	connect( MeGotXPBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( MeGotXPBtn );

	ResearchBtn = new AOColorWidget( MiscTab );
	ResearchBtn->setText( "Research feedback" );
	ResearchBtn->addColorGroup( "ctch_research" );
	connect( ResearchBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( ResearchBtn );

	SkillBtn = new AOColorWidget( MiscTab );
	SkillBtn->setText( "Skill available" );
	SkillBtn->addColorGroup( "CCSkillColor" );
	connect( SkillBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( SkillBtn );

	MyPetBtn = new AOColorWidget( MiscTab );
	MyPetBtn->setText( "My pet" );
	MyPetBtn->addColorGroup( "ctch_mypet" );
	connect( MyPetBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( MyPetBtn );

	OtherPetBtn = new AOColorWidget( MiscTab );
	OtherPetBtn->setText( "n00b's pet" );
	OtherPetBtn->addColorGroup( "ctch_otherpet" );
	connect( OtherPetBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( OtherPetBtn );

	MiscBtn = new AOColorWidget( MiscTab );
	MiscBtn->setText( "Misc *" );
	MiscBtn->setToolTip( "This is used various places, among others Org Leaders chat, and Social chat on TestLive" );
	MiscBtn->addColorGroup( "ctch_misc" );
	MiscBtn->addColorGroup( "CCMiscColor" );
	connect( MiscBtn, SIGNAL( clicked( const QStringList& ) ), this, SLOT( buttonClicked( const QStringList& ) ) );
	MiscLayout->addWidget( MiscBtn );

	TabWidget->addTab( MiscTab, "Misc." );

	/*
	 * Add spacer and help text
	 */
	QSpacerItem* spacer = new QSpacerItem( 1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding );
	BaseLayout->addItem( spacer );

	BasicHelpLabel = new QLabel( this );
	BasicHelpLabel->setText( tr(
		"<b><u>Changing your chatcolors:</u></b><br />"
		"Change the colors you want.<br />"
		"Click <b>Save</b> to save the data.<br />"
		"Launch Anarchy Online.<br /><br />"
		"If you allready have AO running, do this to see your changes:<br />"
		"Press <b>CTRL + SHIFT + F7</b>.<br />"
		"Make the <b>Actions</b> tab active by clicking on it.<br />"
		"Click <b>Reload menus</b>."
		) );
	BaseLayout->addWidget( BasicHelpLabel );
}

BasicModeDlg::~BasicModeDlg()
{
}

void BasicModeDlg::updateColors()
{
	/* basic chat */
	ClanBtn->updateColor();
	PGroupBtn->updateColor();
	TeamBtn->updateColor();
	TellBtn->updateColor();
	VicinityBtn->updateColor();
	WhisperBtn->updateColor();
	ShoutBtn->updateColor();
	OOCBtn->updateColor();

	/* NPC */
	NPCChatBtn->updateColor();
	NPCOOCBtn->updateColor();
	NPCEmoteBtn->updateColor();
	NPCSystemBtn->updateColor();
	NPCQuestionBtn->updateColor();
	NPCDescriptBtn->updateColor();
	NPCTradeBtn->updateColor();

	/* combat */
	MeHitByNanoBtn->updateColor();
	OtherHitByNanoBtn->updateColor();
	MonsterHitMeBtn->updateColor();
	PlayerHitMeBtn->updateColor();
	MeHitOtherBtn->updateColor();
	OtherHitOtherBtn->updateColor();
	OtherHitByPetBtn->updateColor();
	MeHealedBtn->updateColor();

	/* misc */
	ShoppingBtn->updateColor();
	TowerBtn->updateColor();
	MeGotXPBtn->updateColor();
	ResearchBtn->updateColor();
	SkillBtn->updateColor();
	MyPetBtn->updateColor();
	OtherPetBtn->updateColor();
	MiscBtn->updateColor();
}

void BasicModeDlg::setBGColor( AOColor BGColor )
{
	/* basic chat */
	ClanBtn->setBGColor( BGColor );
	PGroupBtn->setBGColor( BGColor );
	TeamBtn->setBGColor( BGColor );
	TellBtn->setBGColor( BGColor );
	VicinityBtn->setBGColor( BGColor );
	WhisperBtn->setBGColor( BGColor );
	ShoutBtn->setBGColor( BGColor );
	OOCBtn->setBGColor( BGColor );

	/* NPC */
	NPCChatBtn->setBGColor( BGColor );
	NPCOOCBtn->setBGColor( BGColor );
	NPCEmoteBtn->setBGColor( BGColor );
	NPCSystemBtn->setBGColor( BGColor );
	NPCQuestionBtn->setBGColor( BGColor );
	NPCDescriptBtn->setBGColor( BGColor );
	NPCTradeBtn->setBGColor( BGColor );

	/* combat */
	MeHitByNanoBtn->setBGColor( BGColor );
	OtherHitByNanoBtn->setBGColor( BGColor );
	MonsterHitMeBtn->setBGColor( BGColor );
	PlayerHitMeBtn->setBGColor( BGColor );
	MeHitOtherBtn->setBGColor( BGColor );
	OtherHitOtherBtn->setBGColor( BGColor );
	OtherHitByPetBtn->setBGColor( BGColor );
	MeHealedBtn->setBGColor( BGColor );

	/* misc */
	ShoppingBtn->setBGColor( BGColor );
	TowerBtn->setBGColor( BGColor );
	MeGotXPBtn->setBGColor( BGColor );
	ResearchBtn->setBGColor( BGColor );
	SkillBtn->setBGColor( BGColor );
	MyPetBtn->setBGColor( BGColor );
	OtherPetBtn->setBGColor( BGColor );
	MiscBtn->setBGColor( BGColor );
}

void BasicModeDlg::buttonClicked( const QStringList &cgs )
{
	emit pickColor( cgs );
}
