/* $Id: settings_dlg.cpp 17 2006-12-15 03:39:43Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
    Copyright (C) 2005 - 2006  Mawerick

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "settings_dlg.h"
#include "aocrayon.h"

#include <QLabel>
#include <QPushButton>
#include <QLineEdit>
#include <QCheckBox>
#include <QLayout>
#include <QMessageBox>
#include <QFileDialog>
#include <QFile>

SettingsDlg::SettingsDlg( QWidget *parent )
	:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	AOPathLayout = new QHBoxLayout;

	AOPathLabel = new QLabel( this );
	AOPathLabel->setText( "AO Install Dir:" );
	AOPathLayout->addWidget( AOPathLabel );

	AOPathBox = new QLineEdit( this );
	connect( AOPathBox, SIGNAL( textChanged(const QString&) ), this, SLOT( setAOPath(const QString&) ) );
	AOPathLayout->addWidget( AOPathBox );

	AOPathBtn = new QPushButton( this );
	AOPathBtn->setText( "..." );
	AOPathBtn->setFixedWidth( 30 );
	connect( AOPathBtn, SIGNAL( clicked() ), this, SLOT( browseAOPath() ) );
	AOPathLayout->addWidget( AOPathBtn );

	BaseLayout->addLayout( AOPathLayout );

	AOPathErrorLabel = new QLabel( this );
	AOPathErrorLabel->setText( "<font color=red><b>Selected path is not a valid AO installation!</b></font>" );
	BaseLayout->addWidget( AOPathErrorLabel );

	ReloadBtn = new QPushButton( this );
	ReloadBtn->setText( "Reload Chat color data" );
	connect( ReloadBtn, SIGNAL( clicked() ), this, SLOT( restoreData() ) );
	BaseLayout->addWidget( ReloadBtn );

	QFrame * Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	RestoreBackupBtn = new QPushButton( this );
	RestoreBackupBtn->setText( "Restore last backup" );
	connect( RestoreBackupBtn, SIGNAL( clicked() ), this, SLOT( restoreBackup() ) );
	BaseLayout->addWidget( RestoreBackupBtn );

	RestoreOriginalBtn = new QPushButton( this );
	RestoreOriginalBtn->setText( "Restore original data" );
	connect( RestoreOriginalBtn, SIGNAL( clicked() ), this, SLOT( restoreOriginalData() ) );
	BaseLayout->addWidget( RestoreOriginalBtn );

	RestoreBundledBtn = new QPushButton( this );
	RestoreBundledBtn->setText( "Restore original data from bundled file" );
	connect( RestoreBundledBtn, SIGNAL( clicked() ), this, SLOT( restoreBundledData() ) );
	BaseLayout->addWidget( RestoreBundledBtn);

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	BGColorLayout = new QHBoxLayout;

	BGColorLabel = new QLabel( this );
	BGColorLabel->setText( "Background color" );
	BGColorLabel->setIndent( 5 );
	BGColorLayout->addWidget( BGColorLabel );

	BGColorBtn = new QPushButton( this );
	BGColorBtn->setIconSize( QSize( 60, 15 ) );
	connect( BGColorBtn, SIGNAL( clicked() ), this, SLOT( pickBGColor() ) );
	BGColorLayout->addWidget( BGColorBtn );

	BaseLayout->addLayout( BGColorLayout );

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	ModeBtn = new QCheckBox( this );
	ModeBtn->setText( "Advanced mode" );
	connect( ModeBtn, SIGNAL( toggled(bool) ), this, SLOT( setMode(bool) ) );
	BaseLayout->addWidget( ModeBtn );

	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
	BaseLayout->addItem( spacer );
}

SettingsDlg::~SettingsDlg()
{
}

void SettingsDlg::browseAOPath()
{
	lookupAOPath();
}

bool SettingsDlg::lookupAOPath()
{
	QString path = QFileDialog::getExistingDirectory( this,
		tr( "Select the folder where Anarchy Online is installed:" ), AOPath );
	if( !path.isEmpty() )
	{
		path.replace( "/", "\\" );
		path.replace( 0, 1, path[0].toUpper() );
		setAOPath( path );
		return TRUE;
	}
	return FALSE;
}

void SettingsDlg::setAOPath( const QString &path )
{
	AOPath = path;
	AOPathBox->setText( path );
	if( QFile::exists( AOPath + GUIPATH + COLORFILE ) )
	{
		AOPathErrorLabel->hide();
		ReloadBtn->show();
	}
	else
	{
		AOPathErrorLabel->show();
		ReloadBtn->hide();
	}
}

QString SettingsDlg::getAOPath()
{
	return AOPath;
}

bool SettingsDlg::confirmAOPath()
{
	while( AOPath.isEmpty() || !QFile::exists( AOPath + GUIPATH + COLORFILE ) )
	{
		if( lookupAOPath() == FALSE )
			return FALSE;
	}
	return TRUE;
}

bool SettingsDlg::backupOriginalData()
{
	QDir GUIDir( AOPath + GUIPATH );
	QFile XmlFile( GUIDir.filePath( COLORFILE ) );

	if( QFile::exists( XmlFile.fileName() + ".orig" ) )
	{
		int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
			"File " COLORFILE ".orig exists. Overwrite?",
			QMessageBox::Yes, QMessageBox::No );
		if( ret = QMessageBox::No )
			return FALSE;
		else
			GUIDir.remove( COLORFILE ".orig" );
	}

	if( !XmlFile.copy( GUIDir.filePath( COLORFILE ".orig" ) ) )
		return FALSE;

	return TRUE;
}

void SettingsDlg::restoreOriginalData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload original data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( AOPath + GUIPATH );
		QFile BackupFile( GUIDir.filePath( COLORFILE ".orig" ) );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsDlg::restoreBundledData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload original data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( AOPath + GUIPATH );
		QFile BackupFile( "TextColors.orig" );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsDlg::restoreBackup()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Restore last backup? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		QDir GUIDir( AOPath + GUIPATH );
		QFile BackupFile( GUIDir.filePath( COLORFILE ".bak" ) );
		GUIDir.remove( COLORFILE );
		BackupFile.copy( GUIDir.filePath( COLORFILE ) );

		emit reloadData();
	}
}

void SettingsDlg::restoreData()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
		tr( "Reload saved data? All changes will be lost." ),
		QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::Yes )
	{
		emit reloadData();
	}
}

void SettingsDlg::setMode( bool mode )
{
	ModeBtn->setChecked( mode );
	emit modeChanged( mode );
}

void SettingsDlg::pickBGColor()
{
	emit pickColor( "background" );
}

void SettingsDlg::setBGColor( AOColor BGColor )
{
	QPixmap temp( 60, 15 );
	temp.fill( BGColor.color() );
	BGColorBtn->setIcon( temp );
}
